==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/cdaudio/translations/cdaudio_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="41"/>
        <source>CD Audio Plugin</source>
        <translation>Plugin Audio CD</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="86"/>
        <source>About CD Audio Plugin</source>
        <translation>Tentang Plugin Audio CD</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="87"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Plugin Audio CD Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="88"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Dikompilasi terhadap libcdio-%1 dan libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="90"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="91"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Penggunaan: buka cdda:// menggunakan dialog Tambah URL atau baris perintah</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Setelan Plugin Audio CD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Perangkat timpa:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limit cd speed:</source>
        <translation>Batas kecepatan cd:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>Gunakan cd-text</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation>CDDB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>Gunakan HTTP sebagai gantinya CDDBP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Alur:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>Bersihkan cache CDDB</translation>
    </message>
</context>
</TS>

==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/Input/cdaudio/translations/cdaudio_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>DecoderCDAudioFactory</name>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="39"/>
        <source>CD Audio Plugin</source>
        <translation>Plugin Audio CD</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="86"/>
        <source>About CD Audio Plugin</source>
        <translation>Tentang Plugin Audio CD</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="87"/>
        <source>Qmmp CD Audio Plugin</source>
        <translation>Plugin Audio CD Qmmp</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="88"/>
        <source>Compiled against libcdio-%1 and libcddb-%2</source>
        <translation>Dikompilasi terhadap libcdio-%1 dan libcddb-%2</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="90"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodercdaudiofactory.cpp" line="91"/>
        <source>Usage: open cdda:/// using Add URL dialog or command line</source>
        <translation>Penggunaan: buka cdda:// menggunakan dialog Tambah URL atau baris perintah</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CD Audio Plugin Settings</source>
        <translation>Setelan Plugin Audio CD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Override device:</source>
        <translation>Perangkat timpa:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Limit cd speed:</source>
        <translation>Batas kecepatan cd:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Use cd-text</source>
        <translation>Gunakan cd-text</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>CDDB</source>
        <translation>CDDB</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Use HTTP instead of CDDBP</source>
        <translation>Gunakan HTTP sebagai gantinya CDDBP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="88"/>
        <source>Server:</source>
        <translation>Server:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="95"/>
        <source>Path:</source>
        <translation>Alur:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Clear CDDB cache</source>
        <translation>Bersihkan cache CDDB</translation>
    </message>
</context>
</TS>
